@@ -100,13 +100,34 @@ import org.wildfly.extension.messaging.activemq.jms.ExternalPooledConnectionFact
  * Domain extension that integrates Apache ActiveMQ 6.
  *
  * <dl>
- * <dt><strong>Current</strong> - WildFly 19</dt>
+ * <dt><strong>Current</strong> - WildFly 22</dt>
  *   <dd>
  *     <ul>
- *       <li>XML namespace: urn:jboss:domain:messaging-activemq:9.0
- *       <li>Management model: 9.0.0
+ *       <li>XML namespace: urn:jboss:domain:messaging-activemq:12.0
+ *       <li>Management model: 12.0.0
  *     </ul>
  *   </dd>
+ * <dt><strong>Current</strong> - WildFly 21</dt>
+ *   <dd>
+ *     <ul>
+ *       <li>XML namespace: urn:jboss:domain:messaging-activemq:11.0
+ *       <li>Management model: 11.0.0
+ *     </ul>
+ *   </dd>
+ * <dt>WildFly 20</dt>
+ *   <dd>
+ *     <ul>
+ *       <li>XML namespace: urn:jboss:domain:messaging-activemq:10.0
+ *       <li>Management model: 10.0.0
+ *     </ul>
+ *   </dd>
+ * <dt>WildFly 19</dt>
+ *  *   <dd>
+ *  *     <ul>
+ *  *       <li>XML namespace: urn:jboss:domain:messaging-activemq:9.0
+ *  *       <li>Management model: 9.0.0
+ *  *     </ul>
+ *  *   </dd>
  * <dt>WildFly 18</dt>
  *   <dd>
  *     <ul>
@@ -220,6 +241,9 @@ public class MessagingExtension implements Extension {
 
     static final String RESOURCE_NAME = MessagingExtension.class.getPackage().getName() + ".LocalDescriptions";
 
+    protected static final ModelVersion VERSION_12_0_0 = ModelVersion.create(12, 0, 0);
+    protected static final ModelVersion VERSION_11_0_0 = ModelVersion.create(11, 0, 0);
+    protected static final ModelVersion VERSION_10_0_0 = ModelVersion.create(10, 0, 0);
     protected static final ModelVersion VERSION_9_0_0 = ModelVersion.create(9, 0, 0);
     protected static final ModelVersion VERSION_8_0_0 = ModelVersion.create(8, 0, 0);
     protected static final ModelVersion VERSION_7_0_0 = ModelVersion.create(7, 0, 0);
@@ -229,15 +253,16 @@ public class MessagingExtension implements Extension {
     protected static final ModelVersion VERSION_3_0_0 = ModelVersion.create(3, 0, 0);
     protected static final ModelVersion VERSION_2_0_0 = ModelVersion.create(2, 0, 0);
     protected static final ModelVersion VERSION_1_0_0 = ModelVersion.create(1, 0, 0);
-    private static final ModelVersion CURRENT_MODEL_VERSION = VERSION_9_0_0;
+    private static final ModelVersion CURRENT_MODEL_VERSION = VERSION_12_0_0;
 
-    private static final MessagingSubsystemParser_9_0 CURRENT_PARSER = new MessagingSubsystemParser_9_0();
+    private static final MessagingSubsystemParser_12_0 CURRENT_PARSER = new MessagingSubsystemParser_12_0();
 
     // ARTEMIS-2273 introduced audit logging at a info level which is rather verbose. We need to use static loggers
     // to ensure the log levels are set to WARN and there is a strong reference to the loggers. This hack will likely
     // be removed in the future.
     private static final Logger BASE_AUDIT_LOGGER;
     private static final Logger MESSAGE_AUDIT_LOGGER;
+    private static final Logger RESOURCE_AUDIT_LOGGER;
 
     static {
         // There is no guarantee that the configured loggers will contain the logger names even if they've been
@@ -256,6 +281,12 @@ public class MessagingExtension implements Extension {
             MESSAGE_AUDIT_LOGGER = Logger.getLogger("org.apache.activemq.audit.message");
             MESSAGE_AUDIT_LOGGER.setLevel(Level.WARNING);
         }
+        if (configuredLoggers.contains("org.apache.activemq.audit.resource")) {
+            RESOURCE_AUDIT_LOGGER = null;
+        } else {
+            RESOURCE_AUDIT_LOGGER = Logger.getLogger("org.apache.activemq.audit.resource");
+            RESOURCE_AUDIT_LOGGER.setLevel(Level.WARNING);
+        }
     }
 
 
@@ -342,6 +373,9 @@ public class MessagingExtension implements Extension {
         context.setSubsystemXmlMapping(SUBSYSTEM_NAME, MessagingSubsystemParser_6_0.NAMESPACE, MessagingSubsystemParser_6_0::new);
         context.setSubsystemXmlMapping(SUBSYSTEM_NAME, MessagingSubsystemParser_7_0.NAMESPACE, MessagingSubsystemParser_7_0::new);
         context.setSubsystemXmlMapping(SUBSYSTEM_NAME, MessagingSubsystemParser_8_0.NAMESPACE, MessagingSubsystemParser_8_0::new);
-        context.setSubsystemXmlMapping(SUBSYSTEM_NAME, MessagingSubsystemParser_9_0.NAMESPACE, CURRENT_PARSER);
+        context.setSubsystemXmlMapping(SUBSYSTEM_NAME, MessagingSubsystemParser_9_0.NAMESPACE, MessagingSubsystemParser_9_0::new);
+        context.setSubsystemXmlMapping(SUBSYSTEM_NAME, MessagingSubsystemParser_10_0.NAMESPACE, MessagingSubsystemParser_10_0::new);
+        context.setSubsystemXmlMapping(SUBSYSTEM_NAME, MessagingSubsystemParser_11_0.NAMESPACE, MessagingSubsystemParser_11_0::new);
+        context.setSubsystemXmlMapping(SUBSYSTEM_NAME, MessagingSubsystemParser_12_0.NAMESPACE, CURRENT_PARSER);
     }
 }
